.. pylleo documentation master file, created by
   sphinx-quickstart on Fri Jul  7 16:32:35 2017.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to pylleo's documentation!
==================================

.. toctree::
   :maxdepth: 2
   :caption: Contents:

   guide
   calibration
   docs
   api


Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
